m-methods: Methods for Function m in Package 'distr'

m-methodsR Documentation

Methods for Function m in Package ‘distr’

Description

m-methods

Methods

m

signature(object = "HyperParameter"): returns the slot m of the parameter of the distribution

m<-

signature(object = "HyperParameter"): modifies the slot m of the parameter of the distribution

m

signature(object = "Hyper"): returns the slot m of the parameter of the distribution

m<-

signature(object = "Hyper"): modifies the slot m of the parameter of the distribution


distr documentation built on July 29, 2026, 3:08 a.m.